@@ -107,7 +107,13 @@ class Destination(
         :param tag: Tag of deployed image. Default: - tag of source
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Destination.ecr)
+            def stub(
+                repository: aws_cdk.aws_ecr.IRepository,
+                *,
+                tag: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
         options = EcrSourceOptions(tag=tag)
 
@@ -135,7 +141,9 @@ class _DestinationProxy(Destination):
         :param role: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Destination.bind)
+            def stub(role: aws_cdk.aws_iam.IGrantable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
         return typing.cast("DestinationConfig", jsii.invoke(self, "bind", [role]))
 
@@ -169,7 +177,14 @@ class DestinationConfig:
         if isinstance(login_config, dict):
             login_config = LoginConfig(**login_config)
         if __debug__:
-            type_hints = typing.get_type_hints(DestinationConfig.__init__)
+            def stub(
+                *,
+                destination_uri: builtins.str,
+                login_config: typing.Union["LoginConfig", typing.Dict[str, typing.Any]],
+                destination_tag: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument destination_uri", value=destination_uri, expected_type=type_hints["destination_uri"])
             check_type(argname="argument login_config", value=login_config, expected_type=type_hints["login_config"])
             check_type(argname="argument destination_tag", value=destination_tag, expected_type=type_hints["destination_tag"])
@@ -237,7 +252,15 @@ class DockerImageDeployment(
         :param source: Source of the image to deploy.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DockerImageDeployment.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                destination: Destination,
+                source: "Source",
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = DockerImageDeploymentProps(destination=destination, source=source)
@@ -257,7 +280,9 @@ class DockerImageDeploymentProps:
         :param source: Source of the image to deploy.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DockerImageDeploymentProps.__init__)
+            def stub(*, destination: Destination, source: "Source") -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument destination", value=destination, expected_type=type_hints["destination"])
             check_type(argname="argument source", value=source, expected_type=type_hints["source"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -303,7 +328,9 @@ class EcrSourceOptions:
         :param tag: Tag of deployed image. Default: - tag of source
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EcrSourceOptions.__init__)
+            def stub(*, tag: typing.Optional[builtins.str] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument tag", value=tag, expected_type=type_hints["tag"])
         self._values: typing.Dict[str, typing.Any] = {}
         if tag is not None:
@@ -348,7 +375,13 @@ class LoginConfig:
         :param region: Region of ECR repository. Default: - undefined if not an ECR repository
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LoginConfig.__init__)
+            def stub(
+                *,
+                login_command: builtins.str,
+                region: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument login_command", value=login_command, expected_type=type_hints["login_command"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -412,7 +445,9 @@ class Source(
         :param path: - path to the directory containing your Dockerfile (not a path to a file).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Source.directory)
+            def stub(path: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         return typing.cast("Source", jsii.sinvoke(cls, "directory", [path]))
 
@@ -450,7 +485,13 @@ class _SourceProxy(Source):
         :param handler_role: The role for the handler.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Source.bind)
+            def stub(
+                scope: constructs.Construct,
+                *,
+                handler_role: aws_cdk.aws_iam.IRole,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         context = SourceContext(handler_role=handler_role)
 
@@ -486,7 +527,14 @@ class SourceConfig:
         if isinstance(login_config, dict):
             login_config = LoginConfig(**login_config)
         if __debug__:
-            type_hints = typing.get_type_hints(SourceConfig.__init__)
+            def stub(
+                *,
+                image_tag: builtins.str,
+                image_uri: builtins.str,
+                login_config: typing.Union[LoginConfig, typing.Dict[str, typing.Any]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument image_tag", value=image_tag, expected_type=type_hints["image_tag"])
             check_type(argname="argument image_uri", value=image_uri, expected_type=type_hints["image_uri"])
             check_type(argname="argument login_config", value=login_config, expected_type=type_hints["login_config"])
@@ -541,7 +589,9 @@ class SourceContext:
         :param handler_role: The role for the handler.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SourceContext.__init__)
+            def stub(*, handler_role: aws_cdk.aws_iam.IRole) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument handler_role", value=handler_role, expected_type=type_hints["handler_role"])
         self._values: typing.Dict[str, typing.Any] = {
             "handler_role": handler_role,
